@@ -1,6 +1,6 @@
 # Almost Free Text (AFT) Parser
 #
-# Copyright (C) 1996-2009 Todd A. Coram. All rights reserved.
+# Copyright (C) 1996-2010 Todd A. Coram. All rights reserved.
 #
 # This perl script parses aft documents and produces output formatted according
 # to an aft 'element' file.  See aft-refman.aft  for additional information.
@@ -20,9 +20,9 @@ use vars qw ($VERSION $version $outputfile $element_type $author $title
 
 $author = '';
 $title = '';
-$VERSION="v5.097";
+$VERSION="v5.098";
 $version=
-  "Almost Free Text $VERSION; Copyright 1996-2009 Todd Coram.";
+  "Almost Free Text $VERSION; Copyright 1996-2010 Todd Coram.";
 
 $element_type="bn-html";		# Default
 $outputfile='';			# Output file
@@ -56,17 +56,18 @@ my $tocout;
 #
 my $mode = 
 {
- inTable => 0,			# Are we in table mode?
- needTableHeaders => 0,		# Used to keep track of table building.
- eatSeparator => 0,		# Used to eat a table separator line.
- inQuote => 0,			# Are we in quote mode?
- inVerbatim => 0,		# Are we in verbatim mode?
- blockedVerbatim => 0,		# Are we in blocked verbatim mode?
- filteredVerbatim => 0,		# Are we in filtered verbatim mode?
- inParagraph => 0,		# Paragraph mode indicator
- inListElement => 0,		# Are we inside of a list element?
- currentSectionLevel => 0,      # Current section we are in.
- haveSections => 0,		# True if we ever go into sections...
+ processing_input => 1,	       # Are we processing input or dumping results?
+ in_table => 0,			# Are we in table mode?
+ need_table_headers => 0,		# Used to keep track of table building.
+ eat_sep => 0,		# Used to eat a table separator line.
+ in_quote => 0,			# Are we in quote mode?
+ in_verb => 0,		# Are we in verbatim mode?
+ in_blocked_verb => 0,		# Are we in blocked verbatim mode?
+ in_filtered_verb => 0,		# Are we in filtered verbatim mode?
+ in_para => 0,		# Paragraph mode indicator
+ in_list_el => 0,		# Are we inside of a list element?
+ cur_sect_level => 0,      # Current section we are in.
+ in_sect => 0,		# True if we ever go into sections...
 };
 
 # Cache (memo) variables. Not state, but artifact used by states.
@@ -149,9 +150,9 @@ my @Functions = (
 # Run AFT from the command line. (The normal way to invoke AFT)
 #
 sub main {
-    &parse_command_line();
-    &load_element_file(&element_file());
-    &setup_symbols();
+    parse_command_line();
+    load_element_file(element_file());
+    setup_symbols();
 
     if ($outputfile eq '') {
         # Use first input filename to construct output filename.
@@ -174,15 +175,15 @@ sub main {
 	  " $INC{element_file()}.\n") if $verbose;
 
 
-    &begin();
+    begin();
 
     # Process each file supplied on the command line.
     #
     foreach my $filename (@ARGV) {
-	&process_file($filename);
+	process_file($filename);
     }
 
-    &end();
+    end();
 
     close(OUT);
     close($tocout) if $tocout; # If we wrote a table of contents, close it.
@@ -200,24 +201,24 @@ sub main {
 sub begin {
     # Initialize our state.
     #
-    &reset_states();
+    reset_states();
 
     # Hold onto the preamble 'til we see if *Title and *Author info is present.
     #
     $holding_preamble = 1;
+    $mode->{processing_input}  = 1;
 }
 
 # Run AFT on a file given its filename.
 #
 sub do_file {
     my($filename) = @_;
-    &load_element_file(&element_file());
-    &begin();
-    &process_file($filename);
-    &end();
+    load_element_file(element_file());
+    begin();
+    process_file($filename);
+    end();
 }
 
-
 # Run AFT on a single line supplied as a string (with a reference filename
 # and line number-- both can be fake.)
 #
@@ -227,8 +228,9 @@ sub do_string {
     
     $_ = $pre_process_line->($_, $fname, $lcnt);
 
+
     # Convert every $tabstop spaces into a tab... e.g. /\ {4}/
-    s/\ {$tabstop}/\t/g if (!$mode->{blockedVerbatim});
+    s/\ {$tabstop}/\t/g if (!$mode->{in_blocked_verb});
     
     # Iterate through all functions until one satisfies the input.
     #
@@ -242,63 +244,68 @@ sub do_string {
     # Always reset states
     # (take us out of whatever mode we may have been in).
     #
-    &reset_states();
+    reset_states();
     
     # Now handle a special case... We need to detect blank lines to
     # determine whether we should end paragraph mode.
     #
-    &reset_paragraph(), return if $_ eq '';
+    reset_paragraph(), return if $_ eq '';
     
     # Otherwise, if not in paragraph mode, enter paragraph mode now.
     #
-    &enter_paragraph() if !$mode->{inParagraph};
+    enter_paragraph() if !$mode->{in_para};
     
     # and  kick out the filtered line.
     #
-    &output(&filter($_)."\n");
+    output(filter($_)."\n");
 }
 
 # Run AFT on a file given its file handle.
 #
 sub do_FH_file {
     my($fh, $filename) = @_;
-    &load_element_file(&element_file());
-    &begin();
-    &process_FH_file($fh, $filename);
-    &end();
+    load_element_file(element_file());
+    begin();
+    process_FH_file($fh, $filename);
+    end();
 }
 
 
 sub output_preamble {
-    &output($AFT_OUTPUT::file_preamble."\n",
+    output($AFT_OUTPUT::file_preamble."\n",
 	    title => $title, author => $author, version => $version);
 }
 
 sub output_postamble {
-    &output($AFT_OUTPUT::file_postamble."\n", aft => &filter($aft_advert));
+    output($AFT_OUTPUT::file_postamble."\n", aft => filter($aft_advert));
 }
 
 sub output_indices {
-  return if (%index == 0);
-  &output($AFT_OUTPUT::elem{'HorizontalLine'}."\n");
-  &do_string("* Index");
-  &do_string("\n");
+  return if (%index == 0);	# no indexed words
+
+  if (defined($AFT_OUTPUT::elem{'PrintIndex'})) {
+      output($AFT_OUTPUT::elem{'PrintIndex'}."\n");
+      return;
+  }
+  output($AFT_OUTPUT::elem{'HorizontalLine'}."\n");
+  do_string("* Index");
+  do_string("\n");
   foreach my $key (sort(keys %index)) {
     next if ($key =~ /iNtErNaLNOTE/);
-    &output($AFT_OUTPUT::elem{'LineBreak'});
-    &output("${key} : ");
+    output($AFT_OUTPUT::elem{'LineBreak'});
+    output("${key} : ");
     foreach my $target (@{$index{$key}}) {
-      &do_string("[*($target)], ");
+      do_string("[*($target)], ");
     }
   }
 }
 
 sub output_notes {
-    &output($AFT_OUTPUT::elem{'HorizontalLine'}."\n");
+    output($AFT_OUTPUT::elem{'HorizontalLine'}."\n");
     my $count = 1;
     foreach my $note (@note) {
-	&do_string("=[(iNtErNaLNOTE$count)]=\n\\[[$count(REFiNtErNaLNOTE$count)]] - $note\n");
-	&output($AFT_OUTPUT::elem{'LineBreak'});
+	do_string("=[(iNtErNaLNOTE$count)]=\n\\[[$count(REFiNtErNaLNOTE$count)]] - $note\n");
+	output($AFT_OUTPUT::elem{'LineBreak'});
 	$count++;
     }
 }
@@ -306,19 +313,20 @@ sub output_notes {
 sub end {
     # End all modes.
     #
-    &reset_states();
-    
+    reset_states();
+    $mode->{processing_input}  = 0;
+
     # If we ever entered sections...
 
-    &enter_section(0), &output($AFT_OUTPUT::elem{'EndSectLevel1'}."\n")
-	if ($mode->{haveSections});
+    enter_section(0), output($AFT_OUTPUT::elem{'EndSectLevel1'}."\n")
+	if ($mode->{in_sect});
     
-    &output_notes() if ($AFT_OUTPUT::elem{'NotesAtEnd?'} eq 'yes');
-#    &output_indices();
+    output_notes() if ($AFT_OUTPUT::elem{'NotesAtEnd?'} eq 'yes');
+    output_indices();
 
     # End output file with Postamble..
     #
-    &output_postamble();
+    output_postamble();
 }
 
 sub parse_command_line {
@@ -355,7 +363,7 @@ sub load_element_file {
 
     # Initialize elements;
     #
-    &AFT_OUTPUT::init_elements();
+    AFT_OUTPUT::init_elements();
 }
 
 # processFile(fname) - Locate, open and process the supplied file.
@@ -371,7 +379,7 @@ sub process_file {
     # Do that voodoo that you do so well.
     #
     print (STDERR "\nProcessing $fname.\n[") if $verbose;
-    &process_FH_file(*IN, $fname);
+    process_FH_file(*IN, $fname);
     
     # Done with it, so close it.
     #
@@ -392,11 +400,11 @@ sub process_FH_file {
 	$lcnt++;
 	chomp;
 	chop if /.*\r$/;  # In case we are unix perl processing a MSDOS .aft file
-	$continued_line .= $1, next LINE if (/(.*)\\$/ and !$mode->{inVerbatim}); # collect continuations
-	&do_string($continued_line.$_, $fname, $lcnt); # process complete line
+	$continued_line .= $1, next LINE if (/(.*)\\$/ and !$mode->{in_verb}); # collect continuations
+	do_string($continued_line.$_, $fname, $lcnt); # process complete line
 	$continued_line = "";
     }
-    &do_string($continued_line, $fname, $lcnt) if $continued_line;
+    do_string($continued_line, $fname, $lcnt) if $continued_line;
 }
 
 
@@ -412,7 +420,7 @@ sub handle_comments {
     # Handle Strike lines (X---)
     #
     /^X-{3,}([^\-]?.*)/ and do {
-	&output($AFT_OUTPUT::elem{'StrikeLine'}."\n",line => $1);
+	output($AFT_OUTPUT::elem{'StrikeLine'}."\n",line => $1);
 	return 1;
     };
     
@@ -424,7 +432,7 @@ sub handle_comments {
 	# #---PASS-'ID' text
 	#
 	$1 =~ /PASS-(\w+)\s+(.*)/ and do {
-	    &output($2) if ($AFT_OUTPUT::elem{'ID'} eq $1);
+	    output($2) if ($AFT_OUTPUT::elem{'ID'} eq $1);
 	    return 1;
 	};
 	
@@ -438,7 +446,7 @@ sub handle_comments {
 	    if ("-$AFT_OUTPUT::elem{'ID'}" eq $1) {
 		$AFT_OUTPUT::pragma_postvar{$2} = $3;
 	    } else {
-		&set_prevar($2,$3) if ($1 !~ /^-/);
+		set_prevar($2,$3) if ($1 !~ /^-/);
 	    }
 	    return 1;
 	};
@@ -453,7 +461,7 @@ sub handle_comments {
 	    return 1;
 	};
 	
-	&output($AFT_OUTPUT::elem{'CommentLine'}."\n",line => $1);
+	output($AFT_OUTPUT::elem{'CommentLine'}."\n",line => $1);
 	return 1;			# regular comment
     };
     
@@ -468,14 +476,14 @@ sub handle_title_preamble {
     # *Title:
     #
     /^\*Title:\s*(.*)$/ and do {
-	$title = &filter($1);
+	$title = filter($1);
 	return 1;
     };
 
     # *Author:
     #
     /^\*Author:\s*(.*)$/ and do {
-	$author = &filter($1);
+	$author = filter($1);
 	return 1;
     };
 
@@ -485,15 +493,15 @@ sub handle_title_preamble {
     if ($holding_preamble) {
 	return 1 if /^\s*$/;		# empty line
 	$holding_preamble = 0;
-	&output_preamble();
+	output_preamble();
 
 	# Now print out title and author if they were collected.
 	# If *Title and *Author were the first two lines in the document,
 	# then we held the preamble until they were collected.
 	# Else we assume that they are not available, so we just print
 	# the preamble.
-	&output($AFT_OUTPUT::elem{"Title"}."\n", title => $title) if $title;
-	&output($AFT_OUTPUT::elem{"Author"}."\n", author => $author) if $author;
+	output($AFT_OUTPUT::elem{"Title"}."\n", title => $title) if $title;
+	output($AFT_OUTPUT::elem{"Author"}."\n", author => $author) if $author;
     }
     return 0;			
 }
@@ -505,7 +513,7 @@ sub handle_includes {
     my $fname = shift; my $lcnt = shift; local($_) = @_;
     
     /^\*(Insert|See File|Include|File):\s*(\S+)/ and do {
-	&process_file($2);
+	process_file($2);
 	return 1;
     };
 
@@ -515,9 +523,9 @@ sub handle_includes {
 	# If there is no automatic table of contents markup, then generate
 	# an AFT style markup.
 	if ($AFT_OUTPUT::elem{$1} eq '') {
-	    &generate_t_oC($fname);
+	    generate_t_oC($fname);
 	} else {
-	    &output($AFT_OUTPUT::elem{$1}."\n");
+	    output($AFT_OUTPUT::elem{$1}."\n");
 	}
 	return 1;
     };
@@ -530,7 +538,7 @@ sub handle_image {
     my $fname = shift; my $lcnt = shift; local($_) = @_;
     
     /^\*(Image|Image-left|Image-center|Image-right):\s*(\S+)/ and do {
-	&output($AFT_OUTPUT::elem{$1}."\n", image =>$2);
+	output($AFT_OUTPUT::elem{$1}."\n", image =>$2);
 	return 1;
     };
     return 0;
@@ -542,7 +550,7 @@ sub handle_ruler {
     my $fname = shift; my $lcnt = shift; local($_) = @_;
     
     /^\-{4,}/ and do {
-	&output($AFT_OUTPUT::elem{'HorizontalLine'}."\n");
+	output($AFT_OUTPUT::elem{'HorizontalLine'}."\n");
 	return 1;
     };
     
@@ -557,11 +565,11 @@ sub handle_sections {
     
     /^(\^*\*{1,7})\s*(.+?)\s*$/ and do {
 	my($sname) = $2;
-	if ($mode->{haveSections} eq 0) {
-	    &output($AFT_OUTPUT::elem{'BeginSectLevel1'}."\n");
-	    $mode->{haveSections} = 1;
+	if ($mode->{in_sect} eq 0) {
+	    output($AFT_OUTPUT::elem{'BeginSectLevel1'}."\n");
+	    $mode->{in_sect} = 1;
 	}
-	&enter_section(length $1);
+	enter_section(length $1);
 
 	$section_number->incr(length $1);
 	my $number = $section_number->dotted();
@@ -572,8 +580,8 @@ sub handle_sections {
 	
 	# print section name
 	#
-	&output($AFT_OUTPUT::elem{$1}."\n", section => $sname, 
-		text => &filter($full_sname), number => $number);
+	output($AFT_OUTPUT::elem{$1}."\n", section => $sname, 
+		text => filter($full_sname), number => $number);
 	
 	# Save the section for the TOC file.
 	#
@@ -602,7 +610,7 @@ sub handle_lists {
     #     <tab>#)
     #     <tab>#.
     #
-    (!$mode->{inVerbatim} and !$mode->{inQuote} and 
+    (!$mode->{in_verb} and !$mode->{in_quote} and 
      (/^(\t{1,})(\*|\[.+\]|\#[.\)]|\d+[.\)])(.*)$/)) and do {
 	 my $rest_of_line = $3;
 	 my $list = '';
@@ -617,15 +625,15 @@ sub handle_lists {
 	 
 	 if ($2 =~ /^\*/) {
 	     $list = 'Bullet';
-	     $le = &prepare_output($AFT_OUTPUT::elem{'BulletListElement'});
+	     $le = prepare_output($AFT_OUTPUT::elem{'BulletListElement'});
 	 } elsif ($2 =~ /^\[(.+)\]/) {
 	     $name = $1,
 	     $list = 'Named',
-	     $le = &prepare_output($AFT_OUTPUT::elem{'NamedListElement'}, 
-				  name => &filter($name));
+	     $le = prepare_output($AFT_OUTPUT::elem{'NamedListElement'}, 
+				  name => filter($name));
 	 } else {
 	     $list = 'Numbered';
-	     $le = &prepare_output($AFT_OUTPUT::elem{'NumberedListElement'});
+	     $le = prepare_output($AFT_OUTPUT::elem{'NumberedListElement'});
 	 }
 	 # Are we nesting yet?
 	 #
@@ -633,8 +641,8 @@ sub handle_lists {
 	     # Increase nest level
 	     #
 	     push(@list_stack,$list);
-	     &end_list_element();
-	     &output($AFT_OUTPUT::elem{'Start'.$list.'List'}."\n");
+	     end_list_element();
+	     output($AFT_OUTPUT::elem{'Start'.$list.'List'}."\n");
 	     
 	     $cur_list_level++;
 	     $current_list = $list;
@@ -642,10 +650,10 @@ sub handle_lists {
 	 while ($cur_list_level > $new_level) {
 	     # Retreat to a previous level
 	     #
-	     &end_list_element();
+	     end_list_element();
 	     $current_list = pop(@list_stack);
 	     
-	     &output($AFT_OUTPUT::elem{'End'.$current_list.'List'}."\n");
+	     output($AFT_OUTPUT::elem{'End'.$current_list.'List'}."\n");
 	     
 	     $cur_list_level--;
 	     $current_list = pop(@list_stack);
@@ -654,40 +662,40 @@ sub handle_lists {
 	 if ($list ne $current_list) {
 	     # Changing horses... A new list type.
 	     #
-	     &end_list_element();
+	     end_list_element();
 	     $current_list = pop(@list_stack);
 	     
-	     &output($AFT_OUTPUT::elem{'End'.$current_list.'List'}."\n");
+	     output($AFT_OUTPUT::elem{'End'.$current_list.'List'}."\n");
 	     push(@list_stack,$list);
 	     $current_list = $list;
-	     &output($AFT_OUTPUT::elem{'Start'.$list.'List'}."\n");
+	     output($AFT_OUTPUT::elem{'Start'.$list.'List'}."\n");
 	 }
-	 &end_list_element();
+	 end_list_element();
 	 
-	 $mode->{inListElement} = 1;
-	 &output($le);		# output element line
-	 &output(&filter($rest_of_line));
+	 $mode->{in_list_el} = 1;
+	 output($le);		# output element line
+	 output(filter($rest_of_line));
 	 return 1;
      };
     
     # Print a continuation of list element if in list mode and tabbed...
     #
     if (scalar(@list_stack) and /^\t\s*(.*)$/) {
-	&output(' '.&filter($1));
+	output(' '.filter($1));
 	return 1;
     }
 
-  &end_list_element();
+  end_list_element();
   return 0;
 }
 
 # Terminate list element.
 #
 sub end_list_element {
-    if ($mode->{inListElement}) {
-	&output($AFT_OUTPUT::elem{'End'.$list_stack[$#list_stack].
+    if ($mode->{in_list_el}) {
+	output($AFT_OUTPUT::elem{'End'.$list_stack[$#list_stack].
 				      'ListElement'}."\n");
-	$mode->{inListElement} = 0;
+	$mode->{in_list_el} = 0;
     }
 }
 
@@ -696,10 +704,10 @@ sub end_list_element {
 sub handle_centered_text {
     my $fname = shift; my $lcnt = shift; local($_) = @_;
     
-    (!scalar(@list_stack) and !$mode->{inVerbatim} and 
-     !$mode->{inQuote} and /^\t{2,}(.*)$/) and do {
-	 &reset_states();	
-	 &output($AFT_OUTPUT::elem{'Center'}."\n", center => &filter($1));
+    (!scalar(@list_stack) and !$mode->{in_verb} and 
+     !$mode->{in_quote} and /^\t{2,}(.*)$/) and do {
+	 reset_states();	
+	 output($AFT_OUTPUT::elem{'Center'}."\n", center => filter($1));
 	 return 1;
      };
     
@@ -711,13 +719,13 @@ sub handle_centered_text {
 sub handle_quoted_text {
     my $fname = shift; my $lcnt = shift; local($_) = @_;
     
-    (!$mode->{inVerbatim} and /^\t\#\s*(.*)$/) and do {
-	if (!$mode->{inQuote}) { # if we aren't in quote mode yet...
-	    &reset_states();
-	    &output($AFT_OUTPUT::elem{'StartQuote'}."\n");
-	    $mode->{inQuote} = 1;
+    (!$mode->{in_verb} and /^\t\#\s*(.*)$/) and do {
+	if (!$mode->{in_quote}) { # if we aren't in quote mode yet...
+	    reset_states();
+	    output($AFT_OUTPUT::elem{'StartQuote'}."\n");
+	    $mode->{in_quote} = 1;
 	}
-	&output(&filter($1)."\n");
+	output(filter($1)."\n");
 	return 1;
     };
     return 0;
@@ -729,30 +737,30 @@ sub handle_table {
     my $fname = shift; my $lcnt = shift; local($_) = @_;
 
     if ($AFT_OUTPUT::pragma_ctl{tableparser} eq 'new') {
-	return &handle_new_table_parser($fname, $lcnt, $_);
+	return handle_new_table_parser($fname, $lcnt, $_);
     }
     # If not in verbatim or quote mode, try table...
     #
-    (!$mode->{inVerbatim} and !$mode->{inQuote} and /^\t\!(.*)$/)  and do {
+    (!$mode->{in_verb} and !$mode->{in_quote} and /^\t\!(.*)$/)  and do {
 	my $ecnt;			# Number of elements.
 	my @elements;
 	my $ftype;
 	
 	# First thing is first... Are we in the table yet?
 	#
-	!$mode->{inTable} and do {
-	    &reset_states();		# start clean
-	    $mode->{inTable} = 1;
+	!$mode->{in_table} and do {
+	    reset_states();		# start clean
+	    $mode->{in_table} = 1;
 	    
 	    # Don't really start the table yet. We need to know how many
 	    # columns we will be dealing with.  Expect table headers next
 	    # time through.
 	    #
-	    $mode->{needTableHeaders} = 1;
+	    $mode->{need_table_headers} = 1;
 	    $1 =~ /([^\!]*)/;
 	    # The first thing we got was a caption. Save it for later.
 	    #
-	    $table_caption = &filter($1);
+	    $table_caption = filter($1);
 	    return 1;
 	};
 
@@ -775,32 +783,32 @@ sub handle_table {
 	# Okay, if this is the 2nd time through then we are looking for
 	# table headers...
 	#
-	if ($mode->{needTableHeaders}) {
+	if ($mode->{need_table_headers}) {
 	    # We got the column count ($ecnt) above, so we assume that
 	    # it will stay consistent. If not, that's someone else's
 	    # problem.
 	    #
 	    
-	    &output($AFT_OUTPUT::elem{'StartTable'}."\n", columns =>$ecnt,
+	    output($AFT_OUTPUT::elem{'StartTable'}."\n", columns =>$ecnt,
 		   caption => $table_caption);
-	    &output($AFT_OUTPUT::elem{'TableCaption'}."\n", 
+	    output($AFT_OUTPUT::elem{'TableCaption'}."\n", 
 		    caption => $table_caption);
-	    $mode->{needTableHeaders} = 0;	# don't need them anymore
+	    $mode->{need_table_headers} = 0;	# don't need them anymore
 	    $ftype = $AFT_OUTPUT::elem{'TableHeader'}; # short hand 
 	} else {
 	    $ftype = $AFT_OUTPUT::elem{'TableElement'}; # short hand
 	}
 	
-	&output($AFT_OUTPUT::elem{'TableRowStart'});
+	output($AFT_OUTPUT::elem{'TableRowStart'});
 	# Now loop through each column element and spit it out.
 	#
 	foreach my $item (@elements) {
-	    &output($ftype, stuff => &filter($item)) if $item;
+	    output($ftype, stuff => filter($item)) if $item;
 	}
 	
 	# End of Table Row
 	#
-	&output($AFT_OUTPUT::elem{'TableRowEnd'}."\n");
+	output($AFT_OUTPUT::elem{'TableRowEnd'}."\n");
 	return 1;
     };
     return 0;
@@ -814,7 +822,7 @@ sub handle_new_table_parser {
     
     # If not in verbatim or quote mode, try table...
     #
-    (!$mode->{inVerbatim} and !$mode->{inQuote} and /^\t\!(.*)$/)  and do {
+    (!$mode->{in_verb} and !$mode->{in_quote} and /^\t\!(.*)$/)  and do {
 	my $ecnt = 0;			# Number of elements.
 	my @elements;
 	my $etype;
@@ -826,20 +834,20 @@ sub handle_new_table_parser {
 
 	# First thing is first... Are we in the table yet?
 	#
-	!$mode->{inTable} and do {
-	    &reset_states();		# start clean
-	    $mode->{inTable} = 1;
+	!$mode->{in_table} and do {
+	    reset_states();		# start clean
+	    $mode->{in_table} = 1;
 	    
 	    # Don't really start the table yet. We need to know how many
 	    # columns we will be dealing with.  Expect table headers next
 	    # time through.
 	    #
-	    $mode->{needTableHeaders} = 1;
+	    $mode->{need_table_headers} = 1;
 	    if ($tline =~ /([^\!]*)/) { $tline = $1; }
 #	    if ($1 =~ /([^\!]*)/) { $tline = $1; }
 	    # The first thing we got was a caption. Save it for later.
 	    #
-	    $table_caption = &filter($tline);
+	    $table_caption = filter($tline);
 	    $mode->{eatOne} = 1;
 	    return 1;
 	};
@@ -851,21 +859,21 @@ sub handle_new_table_parser {
 	# Separator line !--------! means kick out previously accumulated row.
 	#
 	if ($tline =~ /[\-]+!$/) {
-	    &output($AFT_OUTPUT::elem{'TableRowStart'});
-	    if ($mode->{needTableHeaders}) {
+	    output($AFT_OUTPUT::elem{'TableRowStart'});
+	    if ($mode->{need_table_headers}) {
 		$etype = $AFT_OUTPUT::elem{'TableHeader'}; # short hand 
 	    } else {
 		$etype = $AFT_OUTPUT::elem{'TableElement'}; # short hand
 	    }
 	    if (@row_acc) {
-		$mode->{needTableHeaders} = 0 if $mode->{needTableHeaders};
+		$mode->{need_table_headers} = 0 if $mode->{need_table_headers};
 		while (my $item = pop(@row_acc)) {
-		    &output($etype, stuff => &filter($item)) if $item;
+		    output($etype, stuff => filter($item)) if $item;
 		    if (scalar(@row_acc) > 2) {
-			&output($AFT_OUTPUT::elem{'TableElementSep'});
+			output($AFT_OUTPUT::elem{'TableElementSep'});
 		    }
 		}
-		&output($AFT_OUTPUT::elem{'TableRowEnd'}."\n");
+		output($AFT_OUTPUT::elem{'TableRowEnd'}."\n");
 	    }
 	    return 1;
 	}
@@ -886,14 +894,14 @@ sub handle_new_table_parser {
 	# Okay, if this is the 2nd time through then we are looking for
 	# table headers...
 	#
-	if ($mode->{needTableHeaders}) {
+	if ($mode->{need_table_headers}) {
 	    # We got the column count ($ecnt) above, so we assume that
 	    # it will stay consistent. If not, that's someone else's
 	    # problem.
 	    #
-	    &output($AFT_OUTPUT::elem{'StartTable'}."\n", columns =>$ecnt, 
+	    output($AFT_OUTPUT::elem{'StartTable'}."\n", columns =>$ecnt, 
 		    caption => $table_caption);
-	    &output($AFT_OUTPUT::elem{'TableCaption'}."\n", 
+	    output($AFT_OUTPUT::elem{'TableCaption'}."\n", 
 		    caption => $table_caption);
 	}
 
@@ -915,8 +923,8 @@ sub handle_new_table_parser {
 #
 sub handle_blocked_verbatim {
     my $fname = shift; my $lcnt = shift; local($_) = @_;
-    if ($mode->{blockedVerbatim} or $mode->{filteredVerbatim}) {
-	&handle_verbatim($fname,$lcnt,$_);
+    if ($mode->{in_blocked_verb} or $mode->{in_filtered_verb}) {
+	handle_verbatim($fname,$lcnt,$_);
 	return 1;
     }
     return  0;			# drop thru
@@ -929,61 +937,61 @@ sub handle_verbatim {
     #
     /^\^>>/ and do {
 	# Get out of blocked and filtered verbatim mode
-	&reset_states();
+	reset_states();
 	return 1;
     };
     
     # Verbatim Text (and yes, even Quoted Text continuations)
     #
     (/(^\t|^\^\<\<\w*)/ or 
-     $mode->{blockedVerbatim} or $mode->{filteredVerbatim}) and do {
+     $mode->{in_blocked_verb} or $mode->{in_filtered_verb}) and do {
 	 # First, are we starting fresh?
 	 #
-	 (!$mode->{inVerbatim} and !$mode->{inQuote}) and do {
-	     &reset_states();		# start clean
-	     $mode->{inVerbatim} = 1;
+	 (!$mode->{in_verb} and !$mode->{in_quote}) and do {
+	     reset_states();		# start clean
+	     $mode->{in_verb} = 1;
 
 	     # We are just entering the blocked verbatim mode, 
 	     # so just remember this and don't print this line.
 	     #
 	     if ($1 =~ /\^\<\</) {
 		 if ($POSTMATCH =~ /[Ff]/) {
-		     $mode->{filteredVerbatim} = 1;
-		     &output($AFT_OUTPUT::elem{'StartFilteredVerbatim'}."\n");
+		     $mode->{in_filtered_verb} = 1;
+		     output($AFT_OUTPUT::elem{'StartFilteredVerbatim'}."\n");
 		 } else {
-		     $mode->{blockedVerbatim} = 1;
-		     &output($AFT_OUTPUT::elem{'StartBlockedVerbatim'}."\n");
+		     $mode->{in_blocked_verb} = 1;
+		     output($AFT_OUTPUT::elem{'StartBlockedVerbatim'}."\n");
 		 }
 		 return 1;
 	     }			# else
-	     &output($AFT_OUTPUT::elem{'StartVerbatim'}."\n");
+	     output($AFT_OUTPUT::elem{'StartVerbatim'}."\n");
 	 };
 	 
 	 # In quote mode? Just kick out filtered text.
 	 #
-	 &output(&filter($POSTMATCH)."\n"), return 1 if $mode->{inQuote};
+	 output(filter($POSTMATCH)."\n"), return 1 if $mode->{in_quote};
 	 
 	 # We must be in a verbatim mode...
 	 #
 	 
 	 # Kill the first tab
 	 #
-	 s/^\t//g if (!($mode->{blockedVerbatim} or $mode->{filteredVerbatim}));
+	 s/^\t//g if (!($mode->{in_blocked_verb} or $mode->{in_filtered_verb}));
 	 
 	 # Now change all tabs to 8 spaces.
 	 #
-	 s/\t/        /g if (!$mode->{blockedVerbatim});
+	 s/\t/        /g if (!$mode->{in_blocked_verb});
 	 
 	 # Can we really filter FilterVerbatim?
 	 #
-	 if ($mode->{filteredVerbatim} and 
+	 if ($mode->{in_filtered_verb} and 
 	     ($AFT_OUTPUT::elem{'FullFilterFilteredVerbatim?'} =~ /[Yy]/)) {
-	     &output(&filter($_)."\n");
+	     output(filter($_)."\n");
 	 } else {
 	     if ($AFT_OUTPUT::elem{'PreFilterVerbatim?'} =~ /[Yy]/) {
-		 &output(&AFT_OUTPUT::prefilter($_)."\n");
+		 output(AFT_OUTPUT::prefilter($_)."\n");
 	     } else {
-		 &output($_."\n");	# output 'as is'
+		 output($_."\n");	# output 'as is'
 	     }
 	 }
 	 return 1;
@@ -1006,9 +1014,9 @@ sub generate_t_oC {
 	# Read it in.
 	#
 	print (STDERR "\t Reading table of contents from $tocfile...")if $verbose;
-	&process_FH_file(*TOCIN, $tocfile);
+	process_FH_file(*TOCIN, $tocfile);
 	close(TOCIN);
-	&output("\n\n");
+	output("\n\n");
 	print (STDERR "Done.\n") if $verbose;
     };
     if ($verbose) {
@@ -1039,7 +1047,7 @@ sub filter {
     # Now do the prefilters substitutions.
     #
     if ($AFT_OUTPUT::pragma_ctl{prefilter} eq 'yes') {
-	$line =  &AFT_OUTPUT::prefilter($line);
+	$line =  AFT_OUTPUT::prefilter($line);
 	
 	# First, protect ||, \|,  __, \_,  \\, ~~ and \~ 
 	# 
@@ -1084,18 +1092,43 @@ sub filter {
 
     # Handle footnote references
     #
-    $line = &handle_notes($line);
+    $line = handle_notes($line);
+
+    # Handle index references
+    #
+    $line = handle_indexing($line);
 
     # Handle hyper links
     #
-    $line = &handle_links($line);
+    $line = handle_links($line);
     
     
     # Post-filter now. Pass its return up to the caller of filter().
     #
-    &AFT_OUTPUT::postfilter($line) if ($AFT_OUTPUT::pragma_ctl{postfilter} eq 'yes');
+    AFT_OUTPUT::postfilter($line) if ($AFT_OUTPUT::pragma_ctl{postfilter} eq 'yes');
 }
 
+sub handle_indexing {
+    my($line) = @_;
+    my $_cnt;
+
+    if ($mode->{processing_input} == 0) { return $line; }
+    if ($AFT_OUTPUT::pragma_ctl{verbatimsquarebrackets} eq 'yes') {
+	return $line;
+    }
+
+	
+    # Look for new explicitely called out indexes:
+    # =[^indexed]= - Generate a unique target (by appending array length).
+    #
+    $line =~ s/=\[\^([^\]]+?)\]=/
+	  $_cnt=@{$index{$1}},
+	  push(@{$index{$1}},"$1$_cnt"),
+	    prepare_output($AFT_OUTPUT::elem{'Index'},
+                            text => "$1",
+			    target => "$1$_cnt")/eg;
+	return $line;
+}
 
 sub handle_notes {
     my($line) = @_;
@@ -1104,8 +1137,8 @@ sub handle_notes {
     # look for (and replace) [Note: .. ]
     #
     $line =~ s/\[Note:\s*(.*)\]/
-	&handle_links("=[(REFiNtErNaLNOTE".$notenum.")]=").
-	&prepare_output($AFT_OUTPUT::elem{'Note'}, 
+	handle_links("=[(REFiNtErNaLNOTE".$notenum.")]=").
+	prepare_output($AFT_OUTPUT::elem{'Note'}, 
 		       note => "$1",
 		       notereftxt => $notenum,
 		       notetarget => "iNtErNaLNOTE$notenum")/eg
@@ -1122,22 +1155,14 @@ sub handle_links {
 	# =[(target)]=
 	#
 	$line =~ s/=\[\(([^\[]+?)\)\]=/
-	    &prepare_output($AFT_OUTPUT::elem{'Target'},
+	    prepare_output($AFT_OUTPUT::elem{'Target'},
 			   target => "$1", 
 			   text => $AFT_OUTPUT::elem{'NBSPACE'})/eg;
 	
-	# =[^indexed]= - Generate a unique target (by appending array length).
-	#
-	my $_cnt;
-	$line =~ s/=\[\^([^\]]+?)\]=/
-	  $_cnt=@{$index{$1}},
-	  push(@{$index{$1}},"$1$_cnt"),
-	    &prepare_output($AFT_OUTPUT::elem{'Target'},
-			    target => "$1$_cnt", text => "$1")/eg;
 	# =[target]=
 	#
 	$line =~ s/=\[([^\]]+?)\]=/
-	    &prepare_output($AFT_OUTPUT::elem{'Target'},
+	    prepare_output($AFT_OUTPUT::elem{'Target'},
 			    target => "$1", text => "$1")/eg;
 
 				 
@@ -1145,25 +1170,25 @@ sub handle_links {
 	# new [name (url:reference)] style
 	#
 	$line =~ s/([^\\]|^)\[([^\[]+?)\s*\(((http?|file|ftp|mailto):.+?)\)\]/
-	    $1.&prepare_output($AFT_OUTPUT::elem{'URL'},
+	    $1.prepare_output($AFT_OUTPUT::elem{'URL'},
 			      target => "$3", text => "$2", _text=>"$2")/eg;
 	
 	# new [name (:reference)] style (don't capture the : )
 	#
 	$line =~ s/([^\\]|^)\[([^\[]+?)\s*\(:(.+?)\)\]/
-	    $1.&prepare_output($AFT_OUTPUT::elem{'URL'},
+	    $1.prepare_output($AFT_OUTPUT::elem{'URL'},
 			      target => "$3", text => "$2", _text=>"$2")/eg;
 	
 	# new [name (reference)] style
 	#
 	$line =~ s/([^\\]|^)\[([^\[]+?)\s*\((.+?)\)\]/
-	    $1.&prepare_output($AFT_OUTPUT::elem{'InternalReference'},
+	    $1.prepare_output($AFT_OUTPUT::elem{'InternalReference'},
 			      target => "$3", text => "$2")/eg;
 	
 	# new [reference] style
 	#
 	$line =~ s/([^\\]|^)\[([^\[]+?)\]/
-	    $1.&prepare_output($AFT_OUTPUT::elem{'InternalReference'},
+	    $1.prepare_output($AFT_OUTPUT::elem{'InternalReference'},
 			      target => "$2", text => "$2")/eg;
 	
 	$line =~ s/\\\[/"\["/eg;
@@ -1189,46 +1214,46 @@ sub handle_links {
     # generally any character not listed in $_seg
     #
     $line =~ s/(^|[\s\(])($AFT::httpaddr)/
-	"$1".(&prepare_output($AFT_OUTPUT::elem{'URL'},
+	"$1".(prepare_output($AFT_OUTPUT::elem{'URL'},
 			     target => "$2", text => "$2", 
 			     _text=>"")."$3")/eg;
     
     
     # Handle old AFT style Links
     $line =~ s/{\+((http|https|file|ftp|mailto)\:[^{}]+)\+}/
-	&prepare_output($AFT_OUTPUT::elem{'URL'},target => "$1", text => "$1", 
+	prepare_output($AFT_OUTPUT::elem{'URL'},target => "$1", text => "$1", 
 		       _text=>"")/eg;
     
     $line =~ s/{\-([^\@{}]+)[\@]((http|https|file|ftp|mailto)\:[^{}]+)\-}/
-	&prepare_output($AFT_OUTPUT::elem{'URL'},target => "$2", text => "$1",
+	prepare_output($AFT_OUTPUT::elem{'URL'},target => "$2", text => "$1",
 		       _text=>"$1")/eg;
     
     $line =~ s/\{\+\:([^{}]+)\+}/
-	&prepare_output($AFT_OUTPUT::elem{'URL'},target => "$1", text => "$1",
+	prepare_output($AFT_OUTPUT::elem{'URL'},target => "$1", text => "$1",
 		       _text=>"")/eg;
     
     $line =~ s/{\-([^\@{}]+)[\@]\:([^{}]+)\-}/
-	&prepare_output($AFT_OUTPUT::elem{'URL'},target => "$2", text => "$1",
+	prepare_output($AFT_OUTPUT::elem{'URL'},target => "$2", text => "$1",
 		       _text=>"$1")/eg;
     
     $line =~ s/\{\+([^{}]+)\+}/
-	&prepare_output($AFT_OUTPUT::elem{'InternalReference'},
+	prepare_output($AFT_OUTPUT::elem{'InternalReference'},
 		       target => "$1", text => "$1")/eg;
     
     $line =~ s/{\-([^\@{}]+)\-}/
-	&prepare_output($AFT_OUTPUT::elem{'InternalReference'},
+	prepare_output($AFT_OUTPUT::elem{'InternalReference'},
 		       target => "$1", text => "$1")/eg;
     
     $line =~ s/{\-([^\@{}]+)[\@]([^{}]+)\-}/
-	&prepare_output($AFT_OUTPUT::elem{'InternalReference'},
+	prepare_output($AFT_OUTPUT::elem{'InternalReference'},
 		       target => "$2", text => "$1")/eg;
     
     $line =~ s/\}\+([^{}]+)\+\{/
-	&prepare_output($AFT_OUTPUT::elem{'Target'},
+	prepare_output($AFT_OUTPUT::elem{'Target'},
 		       target => "$1", text => "$1")/eg;
     
     $line =~ s/\}\-([^{}]+)\-\{/
-	&prepare_output($AFT_OUTPUT::elem{'Target'},
+	prepare_output($AFT_OUTPUT::elem{'Target'},
 		       target => "$1", text =>$AFT_OUTPUT::elem{'NBSPACE'})/eg;
     
     return $line;
@@ -1237,24 +1262,24 @@ sub handle_links {
 # enterParagraph () - enter paragraph mode.
 #
 sub enter_paragraph {
-    $mode->{inParagraph} = 1;
-    &output($AFT_OUTPUT::elem{'StartParagraph'}."\n");
+    $mode->{in_para} = 1;
+    output($AFT_OUTPUT::elem{'StartParagraph'}."\n");
 }
 
 # resetParagraph () - reset paragraph mode.
 #
 sub reset_paragraph {
     print (STDERR ".") if $verbose;
-    &output($AFT_OUTPUT::elem{'EndSmall'}."\n") if $paragraph->{small};
-    &output($AFT_OUTPUT::elem{'EndStrong'}."\n") if $paragraph->{strong};
-    &output($AFT_OUTPUT::elem{'EndEmphasis'}."\n") if $paragraph->{emphasis};
-    &output($AFT_OUTPUT::elem{'EndTeletype'}."\n") if $paragraph->{teletype};
-    &output($AFT_OUTPUT::elem{'EndParagraph'}."\n") if $mode->{inParagraph};
+    output($AFT_OUTPUT::elem{'EndSmall'}."\n") if $paragraph->{small};
+    output($AFT_OUTPUT::elem{'EndStrong'}."\n") if $paragraph->{strong};
+    output($AFT_OUTPUT::elem{'EndEmphasis'}."\n") if $paragraph->{emphasis};
+    output($AFT_OUTPUT::elem{'EndTeletype'}."\n") if $paragraph->{teletype};
+    output($AFT_OUTPUT::elem{'EndParagraph'}."\n") if $mode->{in_para};
     $paragraph->{small} = 0;
     $paragraph->{strong} = 0;
     $paragraph->{emphasis} = 0;
     $paragraph->{teletype} = 0;
-    $mode->{inParagraph} = 0;
+    $mode->{in_para} = 0;
 }
 
 # enterSection(level) - If we are nesting into a subsection, just keep track.
@@ -1284,34 +1309,34 @@ sub enter_section {
     }
     
     my ($newsectlevel) = @_;
-    &reset_paragraph();
+    reset_paragraph();
     
     # Do the section and section "level" mode popping...
     #
-    if ($mode->{currentSectionLevel} ge $newsectlevel) {
+    if ($mode->{cur_sect_level} ge $newsectlevel) {
 	while (@section_stack gt 0 and $section_stack[-1] ge $newsectlevel) {
-	    $mode->{currentSectionLevel} = pop(@section_stack);
-	    &output($AFT_OUTPUT::elem{'EndSect'.$mode->{currentSectionLevel}}."\n");
-	    if ($mode->{currentSectionLevel} gt 3 and $newsectlevel le 3) {
-		&output($AFT_OUTPUT::elem{'EndSectLevel4'}."\n");
-	    } elsif ($mode->{currentSectionLevel} gt 2 and $newsectlevel le 2) {
-		&output($AFT_OUTPUT::elem{'EndSectLevel3'}."\n");
-	    } elsif ($mode->{currentSectionLevel} gt 1 and $newsectlevel le 1) {
-		&output($AFT_OUTPUT::elem{'EndSectLevel2'}."\n");
+	    $mode->{cur_sect_level} = pop(@section_stack);
+	    output($AFT_OUTPUT::elem{'EndSect'.$mode->{cur_sect_level}}."\n");
+	    if ($mode->{cur_sect_level} gt 3 and $newsectlevel le 3) {
+		output($AFT_OUTPUT::elem{'EndSectLevel4'}."\n");
+	    } elsif ($mode->{cur_sect_level} gt 2 and $newsectlevel le 2) {
+		output($AFT_OUTPUT::elem{'EndSectLevel3'}."\n");
+	    } elsif ($mode->{cur_sect_level} gt 1 and $newsectlevel le 1) {
+		output($AFT_OUTPUT::elem{'EndSectLevel2'}."\n");
 	    }
 	}
     }
     
     # Do the section and section "level" pushing...
     #
-    if (($mode->{currentSectionLevel} le 3) and ($newsectlevel gt 3)) {
-	&output($AFT_OUTPUT::elem{'BeginSectLevel4'}."\n");
-    } elsif (($mode->{currentSectionLevel} le 2) and ($newsectlevel gt 2)) {
-	&output($AFT_OUTPUT::elem{'BeginSectLevel3'}."\n");
-    } elsif (($mode->{currentSectionLevel} le 1) and ($newsectlevel gt 1)) {
-	&output($AFT_OUTPUT::elem{'BeginSectLevel2'}."\n");
+    if (($mode->{cur_sect_level} le 3) and ($newsectlevel gt 3)) {
+	output($AFT_OUTPUT::elem{'BeginSectLevel4'}."\n");
+    } elsif (($mode->{cur_sect_level} le 2) and ($newsectlevel gt 2)) {
+	output($AFT_OUTPUT::elem{'BeginSectLevel3'}."\n");
+    } elsif (($mode->{cur_sect_level} le 1) and ($newsectlevel gt 1)) {
+	output($AFT_OUTPUT::elem{'BeginSectLevel2'}."\n");
     }
-    $mode->{currentSectionLevel} = $newsectlevel;
+    $mode->{cur_sect_level} = $newsectlevel;
     push(@section_stack, $newsectlevel);
 }
 
@@ -1321,34 +1346,34 @@ sub enter_section {
 sub reset_states {
     # Are we in the middle of a table?
     #
-    $mode->{inTable} and (!$mode->{needTableHeaders} and 
-			 &output($AFT_OUTPUT::elem{'EndTable'}."\n"));
+    $mode->{in_table} and (!$mode->{need_table_headers} and 
+			 output($AFT_OUTPUT::elem{'EndTable'}."\n"));
     
     # Since we can only be in one mode at a time, make like a big switch...
     #
   MODE: {
-      &output($AFT_OUTPUT::elem{'EndBlockedVerbatim'}."\n"), last MODE
-	  if $mode->{blockedVerbatim};
-      &output($AFT_OUTPUT::elem{'EndFilteredVerbatim'}."\n"), last MODE
-	  if $mode->{filteredVerbatim};
-      &output($AFT_OUTPUT::elem{'EndVerbatim'}."\n"), last MODE
-	  if $mode->{inVerbatim};
-      &output($AFT_OUTPUT::elem{'EndQuote'}."\n"), last MODE
-	  if $mode->{inQuote};
+      output($AFT_OUTPUT::elem{'EndBlockedVerbatim'}."\n"), last MODE
+	  if $mode->{in_blocked_verb};
+      output($AFT_OUTPUT::elem{'EndFilteredVerbatim'}."\n"), last MODE
+	  if $mode->{in_filtered_verb};
+      output($AFT_OUTPUT::elem{'EndVerbatim'}."\n"), last MODE
+	  if $mode->{in_verb};
+      output($AFT_OUTPUT::elem{'EndQuote'}."\n"), last MODE
+	  if $mode->{in_quote};
       
-      &end_list_element();
+      end_list_element();
       while (my $list = pop(@list_stack)) {
-	  &output($AFT_OUTPUT::elem{'End'.$list.'List'}."\n");
+	  output($AFT_OUTPUT::elem{'End'.$list.'List'}."\n");
       }
   }
     # Now just reset all the variables.
     #
-    $mode->{needTableHeaders} = 0;
-    $mode->{inTable}= 0;
-    $mode->{inQuote} = 0;
-    $mode->{inVerbatim} = 0;
-    $mode->{blockedVerbatim} = 0;
-    $mode->{filteredVerbatim} = 0;
+    $mode->{need_table_headers} = 0;
+    $mode->{in_table}= 0;
+    $mode->{in_quote} = 0;
+    $mode->{in_verb} = 0;
+    $mode->{in_blocked_verb} = 0;
+    $mode->{in_filtered_verb} = 0;
 }
 
 
@@ -1364,7 +1389,7 @@ sub set_prevar {
 # %key% is replaced by value everywhere in text.
 #
 sub output {
-    $my_print->(&prepare_output(@_));
+    $my_print->(prepare_output(@_));
 }
 
 # Prepare a line of text for output.
@@ -1388,8 +1413,8 @@ sub prepare_output {
 	}
     }
     
-    return $str if ($mode->{inVerbatim} and 
-		    !$mode->{filteredVerbatim} and
+    return $str if ($mode->{in_verb} and 
+		    !$mode->{in_filtered_verb} and
 		    $AFT_OUTPUT::pragma_ctl{expandinverbatim} eq 'no');
     
     # Expand the document defined pragma variables.
